==> qt5-tools-debuginfo-5.4.2-1.tar.xz: usr/src/debug/qt5-tools-5.4.2-1/examples/designer/calculatorbuilder/.rcc/qrc_calculatorbuilder.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.4.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-tools/qt5-tools-5.4.2-1.x86_64/src/qttools-opensource-src-5.4.2/examples/designer/calculatorbuilder/calculatorform.ui
  0x0,0x0,0x4,0x5f,
  0x0,
  0x0,0x1e,0xfc,0x78,0x9c,0xed,0x59,0x6d,0x4f,0xdb,0x3a,0x14,0xfe,0xce,0xaf,0x88,
  0xfa,0x75,0xd2,0x4d,0xdb,0xb5,0x40,0x51,0x1a,0x69,0x20,0x6d,0xdc,0x2b,0xb6,0x5d,
  0x6,0x62,0x1f,0x91,0x9b,0x9a,0xd6,0x23,0xb1,0x23,0xc7,0xa1,0xd,0xda,0x8f,0xbf,
  0xb6,0xf3,0x66,0x3b,0x69,0x12,0xba,0x30,0x98,0x2e,0xe2,0xc3,0x7c,0xce,0x49,0x1e,
  0x1f,0x9f,0xe7,0xbc,0x64,0xae,0x13,0x23,0xeb,0x1,0xd2,0x8,0x11,0x3c,0x1f,0x4c,
  0xfe,0x1a,0xe,0x2c,0xf7,0xc0,0x72,0x40,0xcc,0xd6,0x84,0xba,0x8e,0x9d,0x2d,0xb8,
  0xca,0x23,0x41,0x0,0x31,0xe3,0xba,0x7c,0xc5,0x95,0x70,0x1b,0x12,0xca,0x2,0xe0,
  0x51,0xc2,0xd,0xaa,0x24,0xde,0xf0,0x41,0x14,0xb9,0x67,0xc0,0xf7,0x62,0x1f,0x30,
  0x42,0x3f,0x12,0x1a,0xf0,0xb7,0xa5,0x96,0x9b,0x37,0x68,0xb9,0x82,0xcc,0x92,0xf2,
  0x7c,0x70,0xf9,0x5d,0x8a,0x3,0xb,0x83,0x0,0xce,0x7,0xfa,0x5b,0xd2,0x29,0xcb,
  0x9,0x29,0x9,0x21,0x65,0x49,0xf6,0xc,0x59,0xfc,0x80,0x1e,0xfb,0xc2,0xd7,0xa9,
  0xdd,0x72,0x22,0x46,0x11,0x5e,0x59,0x98,0x30,0x3a,0x1f,0x30,0x1a,0xb,0x83,0xb9,
  0x7f,0xfa,0x8c,0xc4,0xb3,0x73,0xc0,0x3a,0xf4,0x15,0x24,0x1,0x64,0x34,0xc9,0xb1,
  0x29,0xdf,0x4b,0xae,0x2c,0x67,0xeb,0xe,0x1d,0x7b,0x9b,0x9,0x89,0x10,0x92,0x4c,
  0xe0,0x67,0x62,0x6b,0x77,0x7c,0x74,0xe8,0xd8,0xe9,0x32,0x55,0xaf,0x21,0x5a,0xad,
  0x99,0x3b,0x3b,0x76,0xec,0x6c,0x29,0x21,0xed,0x1c,0xb3,0xd9,0x93,0x8,0x3d,0xc2,
  0x7f,0x89,0x8f,0xbc,0xc2,0x17,0xa1,0x9,0xa5,0x26,0xdf,0x40,0x68,0x58,0x12,0x42,
  0x77,0xca,0xb7,0x28,0x84,0xd4,0xf8,0xa0,0x1a,0x1f,0xc,0x23,0x67,0x97,0x47,0x4,
  0x32,0x6f,0x2d,0xce,0xa1,0x48,0xd9,0xbb,0x50,0x35,0x2b,0x52,0x7a,0x0,0xdd,0x91,
  0xe6,0x63,0x6c,0x10,0x5e,0x92,0xcd,0x35,0x62,0xbe,0xc1,0x97,0x42,0x91,0x75,0x1a,
  0x23,0x7f,0x9,0x69,0x3,0x4d,0x3e,0x48,0x48,0x5c,0xa6,0xcd,0x27,0x8a,0x96,0x17,
  0x52,0x95,0x83,0xb6,0x65,0x49,0x6d,0x9a,0xd8,0xd9,0x81,0xd4,0xad,0x2a,0x50,0x1,
  0xa0,0x2b,0x84,0xb,0x18,0x1c,0x7,0xb,0x48,0xdd,0x99,0x63,0x67,0xab,0xe,0x10,
  0x51,0x8,0x3c,0xbe,0xb7,0x89,0x71,0xd8,0x88,0x81,0x18,0xc,0x2c,0x4a,0x36,0xf3,
  0x1,0x2f,0x4f,0x8f,0xf8,0x71,0x80,0xe5,0x32,0xc3,0x30,0x22,0x72,0x7e,0x4a,0xb6,
  0x5a,0x44,0xba,0xc4,0xa4,0x29,0x2a,0x15,0x87,0xda,0x22,0x53,0x9e,0x6b,0xa4,0x9d,
  0xab,0x3,0x90,0x11,0x9f,0x5d,0x11,0xaa,0x43,0x12,0x51,0x2a,0xde,0x32,0x62,0x72,
  0x53,0x8d,0x49,0xb7,0xa8,0x34,0xc7,0xa5,0xc6,0x8d,0xf6,0xd8,0xec,0x8e,0x4e,0x27,
  0xb8,0x4a,0x84,0x76,0xc7,0xa8,0x1e,0x4f,0x8d,0x93,0x55,0x69,0xc3,0x17,0x60,0x1,
  0xfd,0xbc,0xb,0xfb,0xa9,0x50,0x3e,0xdd,0x31,0x66,0x3b,0x5a,0xb1,0x84,0x53,0x4b,
  0x7b,0xb7,0x97,0xad,0xfd,0x38,0x7f,0xaa,0x6c,0xcb,0xb9,0x66,0x2b,0xe2,0xba,0xd5,
  0x75,0x89,0xd0,0x25,0xba,0x2e,0x6d,0xd0,0x93,0xa9,0xd6,0xaa,0x73,0x63,0xd6,0xa6,
  0x47,0x33,0xad,0x63,0x17,0xfe,0x1a,0xbb,0x76,0x3a,0x0,0x83,0x5b,0x56,0x1b,0x24,
  0xf7,0x6f,0x1c,0xf2,0x5c,0x1d,0x75,0x8c,0x8c,0xf4,0x97,0x53,0xa6,0x90,0xac,0x51,
  0xda,0x42,0xf0,0x55,0x88,0x30,0xaf,0x86,0x9c,0x62,0x24,0xf6,0xce,0x74,0xa3,0xfe,
  0xa8,0xd6,0x60,0x5f,0x88,0xf2,0xf1,0xe1,0x5e,0x9c,0x8f,0xa7,0xfd,0x71,0x1e,0x90,
  0x38,0x82,0xd7,0x14,0x78,0xf7,0x46,0xc9,0xf2,0x47,0x17,0x84,0xf8,0xae,0x8,0x97,
  0x63,0xcb,0xe5,0x2f,0xb1,0xee,0xd8,0x69,0xc7,0x2b,0xba,0xa3,0x62,0xd4,0x3b,0x63,
  0x6b,0xbd,0xdf,0xbe,0xef,0xa5,0x47,0xba,0x19,0x58,0x85,0xfc,0xe,0x3d,0xae,0x8e,
  0x78,0x93,0x76,0x4e,0xfa,0x74,0xa2,0xb3,0x5e,0x2d,0xf3,0x8c,0xf0,0xa3,0x2a,0xdf,
  0x39,0xdb,0xd3,0x71,0x95,0x6d,0x83,0xeb,0xe,0xe,0x9b,0xb5,0x9d,0x57,0xf6,0xbb,
  0x7d,0x4e,0xf,0x7c,0xb4,0xc2,0xe2,0xb,0x5b,0x47,0xe4,0xdc,0x5f,0xb2,0x93,0x93,
  0xf,0xc2,0x7a,0xc6,0xad,0xf2,0x2b,0x9,0x36,0xb9,0x69,0xe4,0x4c,0x43,0x52,0xbc,
  0x8d,0xcb,0x9d,0x78,0x4f,0x1d,0x97,0xb7,0xe3,0x9e,0x7,0xe6,0xed,0xf8,0x6d,0x64,
  0x9a,0x61,0xca,0x46,0x66,0xd7,0xc8,0x3c,0xdf,0xc8,0xec,0x91,0x6c,0xd,0xf6,0x6d,
  0x64,0xfe,0x59,0x23,0x53,0xab,0xfa,0x5f,0x1f,0x9a,0x35,0x35,0xdf,0xdf,0xd8,0x1c,
  0x8d,0x87,0xaf,0x7d,0x6e,0xce,0xdf,0xe6,0xe6,0xff,0x6f,0x6e,0x8a,0xbf,0xde,0x67,
  0xa7,0xf8,0x7b,0x65,0xf3,0xf3,0x7d,0x4d,0x59,0x29,0xf3,0xf3,0xe8,0x77,0xcc,0xcf,
  0xaf,0x31,0xe3,0xd3,0xe6,0xf7,0x8c,0x4f,0x8d,0x6b,0x22,0x37,0xce,0x2f,0x7b,0xfb,
  0x22,0x5b,0x45,0x7d,0xa9,0xd1,0x39,0xd9,0x8b,0xee,0x71,0x8f,0x74,0xdf,0x51,0xfe,
  0xcf,0xd5,0x1a,0x84,0x66,0xc8,0x20,0xaf,0x57,0xf7,0xf2,0xa3,0x30,0x9f,0x9c,0xf0,
  0x1e,0xe5,0xd8,0x52,0xb3,0x27,0xfc,0x92,0x6c,0x9a,0xf0,0xaf,0x62,0x7c,0xf,0xf1,
  0x7e,0x5b,0xec,0x4e,0xd8,0xe1,0xbe,0xb4,0xd6,0x4e,0x5,0x73,0x2e,0x7c,0x58,0x44,
  0xc4,0x8f,0x19,0xfc,0x59,0x68,0x4e,0x9,0x63,0x24,0xf8,0x69,0x4c,0x8e,0x52,0x3e,
  0xaf,0x28,0x8,0x45,0x8f,0x4,0x33,0xe0,0xdf,0x7e,0x6,0xd1,0x7d,0x69,0xf8,0x27,
  0x8e,0x18,0xba,0x4b,0x4a,0xc5,0x5,0x4,0x4b,0x7e,0x10,0x55,0x71,0xc7,0x4a,0xe9,
  0x9b,0x48,0x86,0x52,0xbc,0x26,0xa1,0x22,0x50,0x80,0x7c,0xed,0xdd,0x1b,0xd3,0x8f,
  0x1b,0x7e,0x76,0xe4,0x65,0x5e,0xe8,0x93,0xae,0xef,0xcf,0x24,0xcd,0xa4,0x18,0x94,
  0xb,0xeb,0x51,0xdd,0x85,0xb5,0x98,0x2d,0xe5,0x45,0xee,0x9e,0x77,0xd3,0xee,0x43,
  0x76,0xd0,0x2b,0x89,0x66,0xa4,0x47,0xeb,0x45,0x73,0xb5,0xda,0xf5,0x4a,0xe7,0x55,
  0x7e,0x3c,0x55,0xcb,0x9c,0x97,0xf8,0xe1,0x4c,0x2d,0xf1,0xfc,0xc7,0x9e,0xa1,0x59,
  0xde,0x45,0x69,0xf,0xcd,0xd2,0xd6,0xca,0xba,0xd5,0x45,0x9e,0x50,0x9c,0x5b,0xc0,
  0x10,0x51,0x6f,0xd6,0xd3,0x5a,0xe3,0x6c,0xe7,0x44,0x6b,0x95,0xd6,0x7e,0xc1,0x8e,
  0x1e,0xe1,0x39,0x52,0xab,0x41,0xfe,0x9a,0xd4,0xfd,0x54,0x93,0x9a,0x53,0x29,0x8,
  0xa6,0x3,0xdc,0x58,0xb2,0x5d,0x9f,0x23,0xca,0x8f,0x1a,0xa3,0x9e,0x73,0x64,0x5d,
  0x14,0xe5,0xb3,0x65,0xc9,0xe8,0xf8,0xd8,0x48,0x13,0xfd,0x3f,0x51,0xf9,0xa7,0xf4,
  0xec,0x85,0xd2,0xa4,0xec,0x4b,0xcf,0x92,0x28,0x93,0x27,0xa5,0xff,0xd3,0x13,0x45,
  0xe9,0x31,0x4a,0xa3,0x72,0x42,0xb4,0xd,0x40,0x78,0x17,0x63,0x4f,0x9c,0xdb,0xe5,
  0x60,0xba,0xe2,0x40,0x10,0x15,0x91,0x98,0x7a,0x30,0x12,0x9f,0xd1,0x8e,0x47,0x30,
  0x86,0xd2,0x26,0x64,0xc7,0x8e,0x91,0x7b,0xf0,0x1f,0x88,0xb2,0xc2,0x36,
  
};

static const unsigned char qt_resource_name[] = {
  // forms
  0x0,0x5,
  0x0,0x6d,0x69,0x43,
  0x0,0x66,
  0x0,0x6f,0x0,0x72,0x0,0x6d,0x0,0x73,
    // calculatorform.ui
  0x0,0x11,
  0x4,0x9f,0xa2,0x19,
  0x0,0x63,
  0x0,0x61,0x0,0x6c,0x0,0x63,0x0,0x75,0x0,0x6c,0x0,0x61,0x0,0x74,0x0,0x6f,0x0,0x72,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,0x6d,0x0,0x2e,0x0,0x75,0x0,0x69,
  
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/forms
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
  // :/forms/calculatorform.ui
  0x0,0x0,0x0,0x10,0x0,0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_calculatorbuilder)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_calculatorbuilder)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_calculatorbuilder)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_calculatorbuilder)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_calculatorbuilder)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_calculatorbuilder)(); }
   } dummy;
}

==> qt5-tools-debuginfo-5.5.1-1.tar.xz: usr/src/debug/qt5-tools-5.5.1-1/examples/designer/calculatorbuilder/.rcc/qrc_calculatorbuilder.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.5.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-tools/qt5-tools-5.5.1-1.i686/src/qttools-opensource-src-5.5.1/examples/designer/calculatorbuilder/calculatorform.ui
  0x0,0x0,0x4,0x5f,
  0x0,
  0x0,0x1e,0xfc,0x78,0x9c,0xed,0x59,0x6d,0x4f,0xdb,0x3a,0x14,0xfe,0xce,0xaf,0x88,
  0xfa,0x75,0xd2,0x4d,0xdb,0xb5,0x40,0x51,0x1a,0x69,0x20,0x6d,0xdc,0x2b,0xb6,0x5d,
  0x6,0x62,0x1f,0x91,0x9b,0x9a,0xd6,0x23,0xb1,0x23,0xc7,0xa1,0xd,0xda,0x8f,0xbf,
  0xb6,0xf3,0x66,0x3b,0x69,0x12,0xba,0x30,0x98,0x2e,0xe2,0xc3,0x7c,0xce,0x49,0x1e,
  0x1f,0x9f,0xe7,0xbc,0x64,0xae,0x13,0x23,0xeb,0x1,0xd2,0x8,0x11,0x3c,0x1f,0x4c,
  0xfe,0x1a,0xe,0x2c,0xf7,0xc0,0x72,0x40,0xcc,0xd6,0x84,0xba,0x8e,0x9d,0x2d,0xb8,
  0xca,0x23,0x41,0x0,0x31,0xe3,0xba,0x7c,0xc5,0x95,0x70,0x1b,0x12,0xca,0x2,0xe0,
  0x51,0xc2,0xd,0xaa,0x24,0xde,0xf0,0x41,0x14,0xb9,0x67,0xc0,0xf7,0x62,0x1f,0x30,
  0x42,0x3f,0x12,0x1a,0xf0,0xb7,0xa5,0x96,0x9b,0x37,0x68,0xb9,0x82,0xcc,0x92,0xf2,
  0x7c,0x70,0xf9,0x5d,0x8a,0x3,0xb,0x83,0x0,0xce,0x7,0xfa,0x5b,0xd2,0x29,0xcb,
  0x9,0x29,0x9,0x21,0x65,0x49,0xf6,0xc,0x59,0xfc,0x80,0x1e,0xfb,0xc2,0xd7,0xa9,
  0xdd,0x72,0x22,0x46,0x11,0x5e,0x59,0x98,0x30,0x3a,0x1f,0x30,0x1a,0xb,0x83,0xb9,
  0x7f,0xfa,0x8c,0xc4,0xb3,0x73,0xc0,0x3a,0xf4,0x15,0x24,0x1,0x64,0x34,0xc9,0xb1,
  0x29,0xdf,0x4b,0xae,0x2c,0x67,0xeb,0xe,0x1d,0x7b,0x9b,0x9,0x89,0x10,0x92,0x4c,
  0xe0,0x67,0x62,0x6b,0x77,0x7c,0x74,0xe8,0xd8,0xe9,0x32,0x55,0xaf,0x21,0x5a,0xad,
  0x99,0x3b,0x3b,0x76,0xec,0x6c,0x29,0x21,0xed,0x1c,0xb3,0xd9,0x93,0x8,0x3d,0xc2,
  0x7f,0x89,0x8f,0xbc,0xc2,0x17,0xa1,0x9,0xa5,0x26,0xdf,0x40,0x68,0x58,0x12,0x42,
  0x77,0xca,0xb7,0x28,0x84,0xd4,0xf8,0xa0,0x1a,0x1f,0xc,0x23,0x67,0x97,0x47,0x4,
  0x32,0x6f,0x2d,0xce,0xa1,0x48,0xd9,0xbb,0x50,0x35,0x2b,0x52,0x7a,0x0,0xdd,0x91,
  0xe6,0x63,0x6c,0x10,0x5e,0x92,0xcd,0x35,0x62,0xbe,0xc1,0x97,0x42,0x91,0x75,0x1a,
  0x23,0x7f,0x9,0x69,0x3,0x4d,0x3e,0x48,0x48,0x5c,0xa6,0xcd,0x27,0x8a,0x96,0x17,
  0x52,0x95,0x83,0xb6,0x65,0x49,0x6d,0x9a,0xd8,0xd9,0x81,0xd4,0xad,0x2a,0x50,0x1,
  0xa0,0x2b,0x84,0xb,0x18,0x1c,0x7,0xb,0x48,0xdd,0x99,0x63,0x67,0xab,0xe,0x10,
  0x51,0x8,0x3c,0xbe,0xb7,0x89,0x71,0xd8,0x88,0x81,0x18,0xc,0x2c,0x4a,0x36,0xf3,
  0x1,0x2f,0x4f,0x8f,0xf8,0x71,0x80,0xe5,0x32,0xc3,0x30,0x22,0x72,0x7e,0x4a,0xb6,
  0x5a,0x44,0xba,0xc4,0xa4,0x29,0x2a,0x15,0x87,0xda,0x22,0x53,0x9e,0x6b,0xa4,0x9d,
  0xab,0x3,0x90,0x11,0x9f,0x5d,0x11,0xaa,0x43,0x12,0x51,0x2a,0xde,0x32,0x62,0x72,
  0x53,0x8d,0x49,0xb7,0xa8,0x34,0xc7,0xa5,0xc6,0x8d,0xf6,0xd8,0xec,0x8e,0x4e,0x27,
  0xb8,0x4a,0x84,0x76,0xc7,0xa8,0x1e,0x4f,0x8d,0x93,0x55,0x69,0xc3,0x17,0x60,0x1,
  0xfd,0xbc,0xb,0xfb,0xa9,0x50,0x3e,0xdd,0x31,0x66,0x3b,0x5a,0xb1,0x84,0x53,0x4b,
  0x7b,0xb7,0x97,0xad,0xfd,0x38,0x7f,0xaa,0x6c,0xcb,0xb9,0x66,0x2b,0xe2,0xba,0xd5,
  0x75,0x89,0xd0,0x25,0xba,0x2e,0x6d,0xd0,0x93,0xa9,0xd6,0xaa,0x73,0x63,0xd6,0xa6,
  0x47,0x33,0xad,0x63,0x17,0xfe,0x1a,0xbb,0x76,0x3a,0x0,0x83,0x5b,0x56,0x1b,0x24,
  0xf7,0x6f,0x1c,0xf2,0x5c,0x1d,0x75,0x8c,0x8c,0xf4,0x97,0x53,0xa6,0x90,0xac,0x51,
  0xda,0x42,0xf0,0x55,0x88,0x30,0xaf,0x86,0x9c,0x62,0x24,0xf6,0xce,0x74,0xa3,0xfe,
  0xa8,0xd6,0x60,0x5f,0x88,0xf2,0xf1,0xe1,0x5e,0x9c,0x8f,0xa7,0xfd,0x71,0x1e,0x90,
  0x38,0x82,0xd7,0x14,0x78,0xf7,0x46,0xc9,0xf2,0x47,0x17,0x84,0xf8,0xae,0x8,0x97,
  0x63,0xcb,0xe5,0x2f,0xb1,0xee,0xd8,0x69,0xc7,0x2b,0xba,0xa3,0x62,0xd4,0x3b,0x63,
  0x6b,0xbd,0xdf,0xbe,0xef,0xa5,0x47,0xba,0x19,0x58,0x85,0xfc,0xe,0x3d,0xae,0x8e,
  0x78,0x93,0x76,0x4e,0xfa,0x74,0xa2,0xb3,0x5e,0x2d,0xf3,0x8c,0xf0,0xa3,0x2a,0xdf,
  0x39,0xdb,0xd3,0x71,0x95,0x6d,0x83,0xeb,0xe,0xe,0x9b,0xb5,0x9d,0x57,0xf6,0xbb,
  0x7d,0x4e,0xf,0x7c,0xb4,0xc2,0xe2,0xb,0x5b,0x47,0xe4,0xdc,0x5f,0xb2,0x93,0x93,
  0xf,0xc2,0x7a,0xc6,0xad,0xf2,0x2b,0x9,0x36,0xb9,0x69,0xe4,0x4c,0x43,0x52,0xbc,
  0x8d,0xcb,0x9d,0x78,0x4f,0x1d,0x97,0xb7,0xe3,0x9e,0x7,0xe6,0xed,0xf8,0x6d,0x64,
  0x9a,0x61,0xca,0x46,0x66,0xd7,0xc8,0x3c,0xdf,0xc8,0xec,0x91,0x6c,0xd,0xf6,0x6d,
  0x64,0xfe,0x59,0x23,0x53,0xab,0xfa,0x5f,0x1f,0x9a,0x35,0x35,0xdf,0xdf,0xd8,0x1c,
  0x8d,0x87,0xaf,0x7d,0x6e,0xce,0xdf,0xe6,0xe6,0xff,0x6f,0x6e,0x8a,0xbf,0xde,0x67,
  0xa7,0xf8,0x7b,0x65,0xf3,0xf3,0x7d,0x4d,0x59,0x29,0xf3,0xf3,0xe8,0x77,0xcc,0xcf,
  0xaf,0x31,0xe3,0xd3,0xe6,0xf7,0x8c,0x4f,0x8d,0x6b,0x22,0x37,0xce,0x2f,0x7b,0xfb,
  0x22,0x5b,0x45,0x7d,0xa9,0xd1,0x39,0xd9,0x8b,0xee,0x71,0x8f,0x74,0xdf,0x51,0xfe,
  0xcf,0xd5,0x1a,0x84,0x66,0xc8,0x20,0xaf,0x57,0xf7,0xf2,0xa3,0x30,0x9f,0x9c,0xf0,
  0x1e,0xe5,0xd8,0x52,0xb3,0x27,0xfc,0x92,0x6c,0x9a,0xf0,0xaf,0x62,0x7c,0xf,0xf1,
  0x7e,0x5b,0xec,0x4e,0xd8,0xe1,0xbe,0xb4,0xd6,0x4e,0x5,0x73,0x2e,0x7c,0x58,0x44,
  0xc4,0x8f,0x19,0xfc,0x59,0x68,0x4e,0x9,0x63,0x24,0xf8,0x69,0x4c,0x8e,0x52,0x3e,
  0xaf,0x28,0x8,0x45,0x8f,0x4,0x33,0xe0,0xdf,0x7e,0x6,0xd1,0x7d,0x69,0xf8,0x27,
  0x8e,0x18,0xba,0x4b,0x4a,0xc5,0x5,0x4,0x4b,0x7e,0x10,0x55,0x71,0xc7,0x4a,0xe9,
  0x9b,0x48,0x86,0x52,0xbc,0x26,0xa1,0x22,0x50,0x80,0x7c,0xed,0xdd,0x1b,0xd3,0x8f,
  0x1b,0x7e,0x76,0xe4,0x65,0x5e,0xe8,0x93,0xae,0xef,0xcf,0x24,0xcd,0xa4,0x18,0x94,
  0xb,0xeb,0x51,0xdd,0x85,0xb5,0x98,0x2d,0xe5,0x45,0xee,0x9e,0x77,0xd3,0xee,0x43,
  0x76,0xd0,0x2b,0x89,0x66,0xa4,0x47,0xeb,0x45,0x73,0xb5,0xda,0xf5,0x4a,0xe7,0x55,
  0x7e,0x3c,0x55,0xcb,0x9c,0x97,0xf8,0xe1,0x4c,0x2d,0xf1,0xfc,0xc7,0x9e,0xa1,0x59,
  0xde,0x45,0x69,0xf,0xcd,0xd2,0xd6,0xca,0xba,0xd5,0x45,0x9e,0x50,0x9c,0x5b,0xc0,
  0x10,0x51,0x6f,0xd6,0xd3,0x5a,0xe3,0x6c,0xe7,0x44,0x6b,0x95,0xd6,0x7e,0xc1,0x8e,
  0x1e,0xe1,0x39,0x52,0xab,0x41,0xfe,0x9a,0xd4,0xfd,0x54,0x93,0x9a,0x53,0x29,0x8,
  0xa6,0x3,0xdc,0x58,0xb2,0x5d,0x9f,0x23,0xca,0x8f,0x1a,0xa3,0x9e,0x73,0x64,0x5d,
  0x14,0xe5,0xb3,0x65,0xc9,0xe8,0xf8,0xd8,0x48,0x13,0xfd,0x3f,0x51,0xf9,0xa7,0xf4,
  0xec,0x85,0xd2,0xa4,0xec,0x4b,0xcf,0x92,0x28,0x93,0x27,0xa5,0xff,0xd3,0x13,0x45,
  0xe9,0x31,0x4a,0xa3,0x72,0x42,0xb4,0xd,0x40,0x78,0x17,0x63,0x4f,0x9c,0xdb,0xe5,
  0x60,0xba,0xe2,0x40,0x10,0x15,0x91,0x98,0x7a,0x30,0x12,0x9f,0xd1,0x8e,0x47,0x30,
  0x86,0xd2,0x26,0x64,0xc7,0x8e,0x91,0x7b,0xf0,0x1f,0x88,0xb2,0xc2,0x36,
  
};

static const unsigned char qt_resource_name[] = {
  // forms
  0x0,0x5,
  0x0,0x6d,0x69,0x43,
  0x0,0x66,
  0x0,0x6f,0x0,0x72,0x0,0x6d,0x0,0x73,
    // calculatorform.ui
  0x0,0x11,
  0x4,0x9f,0xa2,0x19,
  0x0,0x63,
  0x0,0x61,0x0,0x6c,0x0,0x63,0x0,0x75,0x0,0x6c,0x0,0x61,0x0,0x74,0x0,0x6f,0x0,0x72,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,0x6d,0x0,0x2e,0x0,0x75,0x0,0x69,
  
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/forms
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
  // :/forms/calculatorform.ui
  0x0,0x0,0x0,0x10,0x0,0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_calculatorbuilder)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_calculatorbuilder)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_calculatorbuilder)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_calculatorbuilder)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_calculatorbuilder)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_calculatorbuilder)(); }
   } dummy;
}
